@@ -7,14 +7,14 @@
 
 The :class:`GAS` defines the initial client to interact between local and TensorBay.
 It provides some operations on datasets level such as :meth:`GAS.create_dataset`,
-:meth:`GAS.list_dataset_names` and :meth:`GAS.upload_dataset_object`.
+:meth:`GAS.list_dataset_names` and :meth:`GAS.get_dataset`.
 
 AccessKey is required when operating with dataset.
 
 """
 
 import sys
-from typing import Any, Dict, Iterator, Optional, Tuple, Type, Union, overload
+from typing import Any, Dict, Iterator, Optional, Type, Union, overload
 
 from typing_extensions import Literal
 
@@ -30,7 +30,7 @@ class GAS:
     """:class:`GAS` defines the initial client to interact between local and TensorBay.
 
     :class:`GAS` provides some operations on dataset level such as
-    :meth:`GAS.create_dataset` :meth:`GAS.list_dataset_names` and :meth:`GAS.upload_dataset_object`.
+    :meth:`GAS.create_dataset` :meth:`GAS.list_dataset_names` and :meth:`GAS.get_dataset`.
 
     Arguments:
         access_key: User's access key.
@@ -38,15 +38,39 @@ class GAS:
 
     """
 
-    _VERSIONS = {1: "COMMUNITY", 2: "ENTERPRISE"}
-
     def __init__(self, access_key: str, url: str = "") -> None:
         self._client = Client(access_key, url)
 
-    def _get_dataset(self, name: str, commit_id: Optional[str] = None) -> DatasetClientType:
-        dataset_id, is_fusion = self._get_dataset_id_and_type(name)
+    def _get_dataset_with_any_type(self, name: str) -> DatasetClientType:
+        info = self._get_dataset(name)
+        dataset_id = info["id"]
+        is_fusion = info["type"]
+        commit_id = info["HEAD"]["commitId"]
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, dataset_id, self._client, commit_id)
+        return ReturnType(name, dataset_id, self, commit_id=commit_id)
+
+    def _get_dataset(self, name: str) -> Dict[str, Any]:
+        """Get the information of the TensorBay dataset with the input name.
+
+        Arguments:
+            name: The name of the requested dataset.
+
+        Returns:
+            The dict of dataset information.
+
+        Raises:
+            GASDatasetError: When the required dataset does not exist.
+
+        """
+        if not name:
+            raise GASDatasetError(name)
+
+        try:
+            info = next(self._list_datasets(name))
+        except StopIteration as error:
+            raise GASDatasetError(name) from error
+
+        return info
 
     def _list_datasets(
         self,
@@ -70,39 +94,12 @@ class GAS:
             if response["recordSize"] + response["offset"] >= response["totalCount"]:
                 break
 
-    def _get_dataset_id_and_type(self, name: str) -> Tuple[str, bool]:
-        """Get the ID and the type of the TensorBay dataset with the input name.
-
-        Arguments:
-            name: The name of the requested dataset.
-
-        Returns:
-            The tuple of dataset ID and type, True for fusion dataset.
-
-        Raises:
-            GASDatasetError: When the required dataset does not exist.
-
-        """
-        if not name:
-            raise GASDatasetError(name)
-
-        try:
-            info = next(self._list_datasets(name))
-        except StopIteration as error:
-            raise GASDatasetError(name) from error
-
-        return (
-            info["id"],
-            bool(info["type"]),
-        )
-
     @overload
     def create_dataset(
         self,
         name: str,
         is_fusion: Literal[False] = False,
         *,
-        is_continuous: bool = False,
         region: Optional[str] = None,
     ) -> DatasetClient:
         ...
@@ -113,7 +110,6 @@ class GAS:
         name: str,
         is_fusion: Literal[True],
         *,
-        is_continuous: bool = False,
         region: Optional[str] = None,
     ) -> FusionDatasetClient:
         ...
@@ -124,7 +120,6 @@ class GAS:
         name: str,
         is_fusion: bool = False,
         *,
-        is_continuous: bool = False,
         region: Optional[str] = None,
     ) -> DatasetClientType:
         ...
@@ -134,7 +129,6 @@ class GAS:
         name: str,
         is_fusion: bool = False,
         *,
-        is_continuous: bool = False,
         region: Optional[str] = None,  # beijing, hangzhou, shanghai
     ) -> DatasetClientType:
         """Create a TensorBay dataset with given name.
@@ -142,68 +136,64 @@ class GAS:
         Arguments:
             name: Name of the dataset, unique for a user.
             is_fusion: Whether the dataset is a fusion dataset, True for fusion dataset.
-            is_continuous: Whether the data in dataset is continuous.
             region: Region of the dataset to be stored,
                 only support "beijing", "hangzhou", "shanghai", default is "shanghai".
 
         Returns:
             The created :class:`~tensorbay.client.dataset.DatasetClient` instance or
-                :class:`~tensorbay.client.dataset.FusionDatasetClient` instance (is_fusion=True).
+                :class:`~tensorbay.client.dataset.FusionDatasetClient` instance (is_fusion=True),
+                and the status of dataset client is "commit".
 
         """
         post_data = {
             "name": name,
             "type": int(is_fusion),  # normal dataset: 0, fusion dataset: 1
-            "isContinuous": is_continuous,
         }
         if region:
             post_data["region"] = region
 
         response = self._client.open_api_do("POST", "", json=post_data)
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, response.json()["id"], self._client)
+        return ReturnType(name, response.json()["id"], self)
 
     @overload
-    def get_dataset(
-        self, name: str, is_fusion: Literal[False] = False, *, commit_id: Optional[str] = None
-    ) -> DatasetClient:
+    def get_dataset(self, name: str, is_fusion: Literal[False] = False) -> DatasetClient:
         ...
 
     @overload
-    def get_dataset(
-        self, name: str, is_fusion: Literal[True], *, commit_id: Optional[str] = None
-    ) -> FusionDatasetClient:
+    def get_dataset(self, name: str, is_fusion: Literal[True]) -> FusionDatasetClient:
         ...
 
     @overload
-    def get_dataset(
-        self, name: str, is_fusion: bool = False, *, commit_id: Optional[str] = None
-    ) -> DatasetClientType:
+    def get_dataset(self, name: str, is_fusion: bool = False) -> DatasetClientType:
         ...
 
-    def get_dataset(
-        self, name: str, is_fusion: bool = False, *, commit_id: Optional[str] = None
-    ) -> DatasetClientType:
+    def get_dataset(self, name: str, is_fusion: bool = False) -> DatasetClientType:
         """Get a TensorBay dataset with given name and commit ID.
 
         Arguments:
             name: The name of the requested dataset.
             is_fusion: Whether the dataset is a fusion dataset, True for fusion dataset.
-            commit_id: The dataset commit ID.
 
         Returns:
             The requested :class:`~tensorbay.client.dataset.DatasetClient` instance or
-                :class:`~tensorbay.client.dataset.FusionDatasetClient` instance (is_fusion=True).
+                :class:`~tensorbay.client.dataset.FusionDatasetClient` instance (is_fusion=True),
+                and the status of dataset client is "commit".
 
         Raises:
             GASDatasetTypeError: When the requested dataset type is not the same as given.
 
         """
-        dataset_id, type_flag = self._get_dataset_id_and_type(name)
+        info = self._get_dataset(name)
+
+        dataset_id = info["id"]
+        type_flag = info["type"]
+        commit_id = info["HEAD"]["commitId"]
+
         if is_fusion != type_flag:
             raise GASDatasetTypeError(name, type_flag)
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, dataset_id, self._client, commit_id)
+        return ReturnType(name, dataset_id, self, commit_id=commit_id)
 
     def list_dataset_names(self, *, start: int = 0, stop: int = sys.maxsize) -> Iterator[str]:
         """List names of all TensorBay datasets.
@@ -226,14 +216,15 @@ class GAS:
             new_name: New name of the dataset, unique for a user.
 
         """
-        dataset_id, _ = self._get_dataset_id_and_type(name)
+        dataset_id = self._get_dataset(name)["id"]
         patch_data: Dict[str, str] = {"name": new_name}
-        self._client.open_api_do("PATCH", "settings", dataset_id, json=patch_data)
+        self._client.open_api_do("PATCH", "", dataset_id, json=patch_data)
 
     @overload
-    def upload_dataset_object(
+    def upload_dataset(
         self,
         dataset: Dataset,
+        draft_number: Optional[int] = None,
         *,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
@@ -241,9 +232,10 @@ class GAS:
         ...
 
     @overload
-    def upload_dataset_object(
+    def upload_dataset(
         self,
         dataset: FusionDataset,
+        draft_number: Optional[int] = None,
         *,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
@@ -251,18 +243,20 @@ class GAS:
         ...
 
     @overload
-    def upload_dataset_object(
+    def upload_dataset(
         self,
         dataset: Union[Dataset, FusionDataset],
+        draft_number: Optional[int] = None,
         *,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
     ) -> DatasetClientType:
         ...
 
-    def upload_dataset_object(
+    def upload_dataset(
         self,
         dataset: Union[Dataset, FusionDataset],
+        draft_number: Optional[int] = None,
         *,
         jobs: int = 1,
         skip_uploaded_files: bool = False,
@@ -282,6 +276,7 @@ class GAS:
                 :class:`~tensorbay.dataset.dataset. FusionDataset` needs to be uploaded.
             jobs: The number of the max workers in multi-thread upload.
             skip_uploaded_files: Set it to True to skip the uploaded files.
+            draft_number: The draft number.
 
         Returns:
             The :class:`~tensorbay.client.dataset.DatasetClient` or
@@ -290,12 +285,16 @@ class GAS:
 
         """
         dataset_client = self.get_dataset(dataset.name, isinstance(dataset, FusionDataset))
+        if draft_number:
+            dataset_client.checkout(draft_number=draft_number)
+        else:
+            dataset_client.create_draft()
 
         if dataset.catalog:
             dataset_client.upload_catalog(dataset.catalog)
 
         for segment in dataset:
-            dataset_client.upload_segment_object(
+            dataset_client.upload_segment(
                 segment,  # type: ignore[arg-type]
                 jobs=jobs,
                 skip_uploaded_files=skip_uploaded_files,
@@ -304,11 +303,11 @@ class GAS:
         return dataset_client
 
     def delete_dataset(self, name: str) -> None:
-        """Delete a dataset with given name.
+        """Delete a TensorBay dataset with given name.
 
         Arguments:
-            name: Name of the :class:`~tensorbay.dataset.dataset.Dataset`, unique for a user.
+            name: Name of the dataset, unique for a user.
 
         """
-        dataset_id, _ = self._get_dataset_id_and_type(name)
+        dataset_id = self._get_dataset(name)["id"]
         self._client.open_api_do("DELETE", "", dataset_id)
